---------------------------------------------------------------------------
-- Project:  ReactionTimer2000
-- Entity:   HEX2LEDA           
--
-- Author:   P. Claus
-- Date:     11.02.99
---------------------------------------------------------------------------
-- HEX2LEDA: HEX-to-seven-segment decoder for common anode displays
--
-- ------------------------------------------------------------------------
-- History: 22.07.99  Implementation by Peter Claus
--          07.07.00  Version for common anode LEDs
--                    common kathode displays need external inverter
-- ------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;

entity HEX2LEDA is
    port (
        HEX : in std_logic_vector (3 downto 0);    -- HEX input signal
        LEDN: out std_logic_vector (6 downto 0)    -- 7 segment output
         );                                        -- inverted
end HEX2LEDA;


architecture HEX2LEDA_BEHAVE of HEX2LEDA is
signal LED: std_logic_vector (6 downto 0);

begin
  DECODE_P1: process (HEX)                         -- process declaration
    											   -- for 7 segment encoding
--
--   segment encoding:
--        a
--       ---                   g, f, e, d, c, b, a
--    f |   | b                6, 5, 4, 3, 2, 1, 0
--       ---   <- g            
--    e |   | c                
--       ---
--        d
--
    begin
    case HEX is                                    -- 7-segment decoding
      when "0001" =>    LED <= "0000110";  -- 1
      when "0010" =>    LED <= "1011011";  -- 2
      when "0011" =>    LED <= "1001111";  -- 3
      when "0100" =>    LED <= "1100110";  -- 4
      when "0101" =>    LED <= "1101101";  -- 5
      when "0110" =>    LED <= "1111101";  -- 6
      when "0111" =>    LED <= "0000111";  -- 7
      when "1000" =>    LED <= "1111111";  -- 8
      when "1001" =>    LED <= "1101111";  -- 9
      when "1010" =>    LED <= "1110111";  -- A
      when "1011" =>    LED <= "1111100";  -- b
      when "1100" =>    LED <= "0111001";  -- C
      when "1101" =>    LED <= "1011110";  -- d
      when "1110" =>    LED <= "1111001";  -- E
      when "1111" =>    LED <= "1110001";  -- F
      when others =>    LED <= "0111111";  -- 0
    end case;
   
  end process DECODE_P1;
  
  LEDN <= NOT(LED);                               -- concurrent assignment
                                                  -- for common anode LED        
end HEX2LEDA_BEHAVE;